synphot
=======

.. image:: https://readthedocs.org/projects/synphot/badge/?version=latest
    :target: http://synphot.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://travis-ci.org/spacetelescope/synphot_refactor.svg?branch=master
    :target: https://travis-ci.org/spacetelescope/synphot_refactor

.. image:: https://ci.appveyor.com/api/projects/status/jc4f77cpng8iyvnd/branch/master?svg=true
    :target: https://ci.appveyor.com/project/pllim/synphot-refactor/branch/master

.. image:: https://coveralls.io/repos/github/spacetelescope/synphot_refactor/badge.svg?branch=master
    :target: https://coveralls.io/github/spacetelescope/synphot_refactor?branch=master

This is a replacement for IRAF STSDAS SYNPHOT and ASTROLIB PYSYNPHOT,
utilizing Astropy and covering the non-instrument specific portions
of the old packages.
